Boxes

Struct Boxes 

pub struct Boxes { /* private fields */ }
A helper object for managing inbox/outbox.

Implementations

Source

impl Boxes

pub fn manager(&self) -> &Manager

Returns the inbox/outbox manager.

pub fn manager_mut(&mut self) -> &mut Manager

Returns the inbox/outbox manager as a mutable reference.

pub fn user(&self) -> &User

Returns the user object cached on this helper object.

pub fn user_mut(&mut self) -> &mut User

Returns the user object as a mutable reference, ceched on this helper object.

pub fn unread_count(&self) -> usize

Returns the count of unread messages.

pub fn set_unread_count(&mut self, count: usize)

Set the count of unread messages.

pub fn increment_unread_count(&mut self)

Increments the count of unread messages.

pub fn decrement_unread_count(&mut self)

Decrements the count of unread messages.

pub fn selected_identity_index(&self) -> Option<usize>

Returns the index of the selected identity.

pub fn set_selected_identity_index(&mut self, value: Option<usize>)

Sets the index of the selected identity.

pub fn selected_contact_index(&self) -> Option<usize>

Returns the index of the selected contact.

pub fn set_selected_contact_index(&mut self, value: Option<usize>)

Sets the index of the selected contact.